Spec ID sanitization and validation
This module provides functionality to sanitize and validate spec IDs to ensure they are safe for use as directory names and identifiers.
Enums
- Spec
IdError - Error type for spec ID validation failures
Functions
- sanitize_
spec_ id - Sanitizes a spec ID to ensure it’s safe for filesystem use