Module spec_id

Module spec_id 

Spec ID sanitization and validation

This module provides functionality to sanitize and validate spec IDs to ensure they are safe for use as directory names and identifiers.

Enums

SpecIdError
Error type for spec ID validation failures

Functions

sanitize_spec_id
Sanitizes a spec ID to ensure it’s safe for filesystem use